"""Add game7 testnet

Revision ID: db9559f9566c
Revises: 211646463e9f
Create Date: 2024-08-05 16:24:26.159323

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = "db9559f9566c"
down_revision: Union[str, None] = "211646463e9f"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "game7_testnet_labels",
        sa.Column("id", sa.UUID(), nullable=False),
        sa.Column("label", sa.VARCHAR(length=256), nullable=False),
        sa.Column("transaction_hash", sa.VARCHAR(length=128), nullable=False),
        sa.Column("log_index", sa.Integer(), nullable=True),
        sa.Column("block_number", sa.BigInteger(), nullable=False),
        sa.Column("block_hash", sa.VARCHAR(length=256), nullable=False),
        sa.Column("block_timestamp", sa.BigInteger(), nullable=False),
        sa.Column("caller_address", sa.LargeBinary(), nullable=True),
        sa.Column("origin_address", sa.LargeBinary(), nullable=True),
        sa.Column("address", sa.LargeBinary(), nullable=False),
        sa.Column("label_name", sa.Text(), nullable=True),
        sa.Column("label_type", sa.VARCHAR(length=64), nullable=True),
        sa.Column("label_data", postgresql.JSONB(astext_type=sa.Text()), nullable=True),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_game7_testnet_labels")),
        sa.UniqueConstraint("id", name=op.f("uq_game7_testnet_labels_id")),
    )
    op.create_index(
        "ix_game7_testnet_labels_addr_block_num",
        "game7_testnet_labels",
        ["address", "block_number"],
        unique=False,
    )
    op.create_index(
        "ix_game7_testnet_labels_addr_block_ts",
        "game7_testnet_labels",
        ["address", "block_timestamp"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_testnet_labels_address"),
        "game7_testnet_labels",
        ["address"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_testnet_labels_block_number"),
        "game7_testnet_labels",
        ["block_number"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_testnet_labels_caller_address"),
        "game7_testnet_labels",
        ["caller_address"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_testnet_labels_label"),
        "game7_testnet_labels",
        ["label"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_testnet_labels_label_name"),
        "game7_testnet_labels",
        ["label_name"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_testnet_labels_label_type"),
        "game7_testnet_labels",
        ["label_type"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_testnet_labels_origin_address"),
        "game7_testnet_labels",
        ["origin_address"],
        unique=False,
    )
    op.create_index(
        op.f("ix_game7_testnet_labels_transaction_hash"),
        "game7_testnet_labels",
        ["transaction_hash"],
        unique=False,
    )
    op.create_index(
        "uk_game7_testnet_labels_tx_hash_log_idx_evt",
        "game7_testnet_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer' and label_type='event'"),
    )
    op.create_index(
        "uk_game7_testnet_labels_tx_hash_log_idx_evt_raw",
        "game7_testnet_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_game7_testnet_labels_tx_hash_tx_call",
        "game7_testnet_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_game7_testnet_labels_tx_hash_tx_call_raw",
        "game7_testnet_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        "uk_game7_testnet_labels_tx_hash_tx_call_raw",
        table_name="game7_testnet_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_game7_testnet_labels_tx_hash_tx_call",
        table_name="game7_testnet_labels",
        postgresql_where=sa.text("label='seer' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_game7_testnet_labels_tx_hash_log_idx_evt_raw",
        table_name="game7_testnet_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_game7_testnet_labels_tx_hash_log_idx_evt",
        table_name="game7_testnet_labels",
        postgresql_where=sa.text("label='seer' and label_type='event'"),
    )
    op.drop_index(
        op.f("ix_game7_testnet_labels_transaction_hash"),
        table_name="game7_testnet_labels",
    )
    op.drop_index(
        op.f("ix_game7_testnet_labels_origin_address"),
        table_name="game7_testnet_labels",
    )
    op.drop_index(
        op.f("ix_game7_testnet_labels_label_type"), table_name="game7_testnet_labels"
    )
    op.drop_index(
        op.f("ix_game7_testnet_labels_label_name"), table_name="game7_testnet_labels"
    )
    op.drop_index(
        op.f("ix_game7_testnet_labels_label"), table_name="game7_testnet_labels"
    )
    op.drop_index(
        op.f("ix_game7_testnet_labels_caller_address"),
        table_name="game7_testnet_labels",
    )
    op.drop_index(
        op.f("ix_game7_testnet_labels_block_number"), table_name="game7_testnet_labels"
    )
    op.drop_index(
        op.f("ix_game7_testnet_labels_address"), table_name="game7_testnet_labels"
    )
    op.drop_index(
        "ix_game7_testnet_labels_addr_block_ts", table_name="game7_testnet_labels"
    )
    op.drop_index(
        "ix_game7_testnet_labels_addr_block_num", table_name="game7_testnet_labels"
    )
    op.drop_table("game7_testnet_labels")
    # ### end Alembic commands ###
